Uses pillow and piexif to modify images, see [optima35](https://gitlab.com/CodeByMrFinchum/optima35) gitlab for more information.
Install [OptimaLab35](https://pypi.org/project/OptimaLab35/) in pip for a GUI.
